@@ -2,7 +2,8 @@
 
 Also supports the `-l` option.
 
-The "Magic" syntax is not supported since the `jobs` command is a shell builtin.
+The "Magic" syntax is not supported since the `jobs` command is a shell
+builtin.
 
 Usage (cli):
 
@@ -10,6 +11,11 @@ Usage (cli):
 
 Usage (module):
 
+    import jc
+    result = jc.parse('jobs', jobs_command_output)
+
+    or
+
     import jc.parsers.jobs
     result = jc.parsers.jobs.parse(jobs_command_output)
 
@@ -97,8 +103,6 @@ class info():
     description = '`jobs` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
-
-    # compatible options: linux, darwin, cygwin, win32, aix, freebsd
     compatible = ['linux', 'darwin', 'cygwin', 'aix', 'freebsd']
     magic_commands = ['jobs']
 
@@ -134,7 +138,7 @@ def parse(data, raw=False, quiet=False):
     Parameters:
 
         data:        (string)  text data to parse
-        raw:         (boolean) output preprocessed JSON if True
+        raw:         (boolean) unprocessed output if True
         quiet:       (boolean) suppress warning messages if True
 
     Returns:
