@@ -4,11 +4,17 @@ Options supported:
 - `lbaR1`
 - `--time-style=full-iso`
 
-Note: The `-1`, `-l`, or `-b` option of `ls` should be used to correctly parse filenames that include newline characters. Since `ls` does not encode newlines in filenames when outputting to a pipe it will cause `jc` to see multiple files instead of a single file if `-1`, `-l`, or `-b` is not used. Alternatively, `vdir` can be used, which is the same as running `ls -lb`.
+Note: The `-1`, `-l`, or `-b` option of `ls` should be used to correctly
+parse filenames that include newline characters. Since `ls` does not encode
+newlines in filenames when outputting to a pipe it will cause `jc` to see
+multiple files instead of a single file if `-1`, `-l`, or `-b` is not used.
+Alternatively, `vdir` can be used, which is the same as running `ls -lb`.
 
-The `epoch` calculated timestamp field is naive (i.e. based on the local time of the system the parser is run on)
+The `epoch` calculated timestamp field is naive. (i.e. based on the local
+time of the system the parser is run on)
 
-The `epoch_utc` calculated timestamp field is timezone-aware and is only available if the timezone field is UTC.
+The `epoch_utc` calculated timestamp field is timezone-aware and is only
+available if the timezone field is UTC.
 
 Usage (cli):
 
@@ -20,6 +26,11 @@ Usage (cli):
 
 Usage (module):
 
+    import jc
+    result = jc.parse('ls', ls_command_output)
+
+    or
+
     import jc.parsers.ls
     result = jc.parsers.ls.parse(ls_command_output)
 
@@ -35,11 +46,15 @@ Schema:
         "group":        string,
         "size":         integer,
         "date":         string,
-        "epoch":        integer,     # naive timestamp if date field exists and can be converted
-        "epoch_utc":    integer      # timezone aware timestamp if date field is in UTC and can be converted
+        "epoch":        integer,     # [0]
+        "epoch_utc":    integer      # [1]
       }
     ]
 
+    [0] naive timestamp if date field exists and can be converted.
+    [1] timezone aware timestamp if date field is in UTC and can
+        be converted.
+
 Examples:
 
     $ ls /usr/bin | jc --ls -p
@@ -111,8 +126,6 @@ class info():
     description = '`ls` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
-
-    # compatible options: linux, darwin, cygwin, win32, aix, freebsd
     compatible = ['linux', 'darwin', 'cygwin', 'aix', 'freebsd']
     magic_commands = ['ls', 'vdir']
 
@@ -155,7 +168,7 @@ def parse(data, raw=False, quiet=False):
     Parameters:
 
         data:        (string)  text data to parse
-        raw:         (boolean) output preprocessed JSON if True
+        raw:         (boolean) unprocessed output if True
         quiet:       (boolean) suppress warning messages if True
 
     Returns:
