@@ -2,9 +2,13 @@
 
 Blank or missing elements are set to `null`.
 
-The `original_install_date_epoch` and `system_boot_time_epoch` calculated timestamp fields are naive (i.e. based on the local time of the system the parser is run on)
+The `original_install_date_epoch` and `system_boot_time_epoch` calculated
+timestamp fields are naive. (i.e. based on the local time of the system the
+parser is run on)
 
-The `original_install_date_epoch_utc` and `system_boot_time_epoch_utc` calculated timestamp fields are timezone-aware and are only available if the timezone field is UTC.
+The `original_install_date_epoch_utc` and `system_boot_time_epoch_utc`
+calculated timestamp fields are timezone-aware and are only available if
+the timezone field is UTC.
 
 Usage (cli):
 
@@ -12,6 +16,11 @@ Usage (cli):
 
 Usage (module):
 
+    import jc
+    result = jc.parse('systeminfo', systeminfo_command_output)
+
+    or
+
     import jc.parsers.systeminfo
     result = jc.parsers.systeminfo.parse(systeminfo_command_output)
 
@@ -28,11 +37,11 @@ Schema:
       "registered_organization":                    string,
       "product_id":                                 string,
       "original_install_date":                      string,
-      "original_install_date_epoch":                integer,     # naive timestamp
-      "original_install_date_epoch_utc":            integer,     # timezone-aware timestamp
+      "original_install_date_epoch":                integer,     # [0]
+      "original_install_date_epoch_utc":            integer,     # [1]
       "system_boot_time":                           string,
-      "system_boot_time_epoch":                     integer,     # naive timestamp
-      "system_boot_time_epoch_utc":                 integer,     # timezone-aware timestamp
+      "system_boot_time_epoch":                     integer,     # [0]
+      "system_boot_time_epoch_utc":                 integer,     # [1]
       "system_manufacturer":                        string,
       "system_model":                               string,
       "system_type":                                string,
@@ -77,6 +86,9 @@ Schema:
       }
     }
 
+    [0] naive timestamp
+    [1] timezone-aware timestamp
+
 Examples:
 
     $ systeminfo | jc --systeminfo -p
@@ -209,9 +221,6 @@ class info:
     description = "`systeminfo` command parser"
     author = "Jon Smith"
     author_email = "jon@rebelliondefense.com"
-    # details = 'enter any other details here'
-
-    # compatible options: linux, darwin, cygwin, win32, aix, freebsd
     compatible = ["win32"]
     magic_commands = ["systeminfo"]
 
@@ -229,11 +238,12 @@ def _process(proc_data):
 
     Returns:
 
-        Dictionary. Some keys are optional. Example: a system without hyper-v capabilities
-        will not have a 'hyperv_requirements' key, and a system already running hyper-v
-        will have an empty "hyperv_requirements" object.
+        Dictionary. Structured data to conform to the schema.
 
-        Structured data to conform to the schema.
+        Some keys are optional. For example, a system without
+        hyper-v capabilities will not have a 'hyperv_requirements' key, and
+        a system already running hyper-v will have an empty
+        "hyperv_requirements" object.
     """
     # convert empty strings to None/null
     for item in proc_data:
@@ -296,7 +306,7 @@ def parse(data, raw=False, quiet=False):
     Parameters:
 
         data:        (string)  text data to parse
-        raw:         (boolean) output preprocessed JSON if True
+        raw:         (boolean) unprocessed output if True
         quiet:       (boolean) suppress warning messages if True
 
     Returns:
