@@ -4,76 +4,100 @@
 
 Options supported: `-a`, `-w`, `-d`, `-t`
 
-The `epoch` calculated timestamp field is naive (i.e. based on the local time of the system the parser is run on)
+The `epoch` calculated timestamp field is naive. (i.e. based on the local
+time of the system the parser is run on)
 
-The `epoch_utc` calculated timestamp field is timezone-aware and is only available if the timezone field is UTC.
+The `epoch_utc` calculated timestamp field is timezone-aware and is only
+available if the timezone field is UTC.
 
 Usage (cli):
 
     $ vmstat | jc --vmstat-s
 
-> Note: When piping `jc` converted `vmstat` output to other processes it may appear the output is hanging due to the OS pipe buffers. This is because `vmstat` output is too small to quickly fill up the buffer. Use the `-u` option to unbuffer the `jc` output if you would like immediate output. See the [readme](https://github.com/kellyjonbrazil/jc/tree/master#unbuffering-output) for more information.
+> Note: When piping `jc` converted `vmstat` output to other processes it may
+appear the output is hanging due to the OS pipe buffers. This is because
+`vmstat` output is too small to quickly fill up the buffer. Use the `-u`
+option to unbuffer the `jc` output if you would like immediate output. See
+the [readme](https://github.com/kellyjonbrazil/jc/tree/master#unbuffering-output)
+for more information.
 
 Usage (module):
 
+    import jc
+    # result is an iterable object (generator)
+    result = jc.parse('vmstat_s', vmstat_command_output.splitlines())
+    for item in result:
+        # do something
+
+    or
+
     import jc.parsers.vmstat_s
-    result = jc.parsers.vmstat_s.parse(vmstat_command_output.splitlines())    # result is an iterable object
+    # result is an iterable object (generator)
+    result = jc.parsers.vmstat_s.parse(vmstat_command_output.splitlines())
     for item in result:
         # do something
 
 Schema:
 
     {
-      "runnable_procs":                    integer,
-      "uninterruptible_sleeping_procs":    integer,
-      "virtual_mem_used":                  integer,
-      "free_mem":                          integer,
-      "buffer_mem":                        integer,
-      "cache_mem":                         integer,
-      "inactive_mem":                      integer,
-      "active_mem":                        integer,
-      "swap_in":                           integer,
-      "swap_out":                          integer,
-      "blocks_in":                         integer,
-      "blocks_out":                        integer,
-      "interrupts":                        integer,
-      "context_switches":                  integer,
-      "user_time":                         integer,
-      "system_time":                       integer,
-      "idle_time":                         integer,
-      "io_wait_time":                      integer,
-      "stolen_time":                       integer,
-      "disk":                              string,
-      "total_reads":                       integer,
-      "merged_reads":                      integer,
-      "sectors_read":                      integer,
-      "reading_ms":                        integer,
-      "total_writes":                      integer,
-      "merged_writes":                     integer,
-      "sectors_written":                   integer,
-      "writing_ms":                        integer,
-      "current_io":                        integer,
-      "io_seconds":                        integer,
-      "timestamp":                         string,
-      "timezone":                          string,
-      "epoch":                             integer,     # naive timestamp if -t flag is used
-      "epoch_utc":                         integer      # aware timestamp if -t flag is used and UTC TZ
-      "_jc_meta":                                       # This object only exists if using -qq or ignore_exceptions=True
+      "runnable_procs":                   integer,
+      "uninterruptible_sleeping_procs":   integer,
+      "virtual_mem_used":                 integer,
+      "free_mem":                         integer,
+      "buffer_mem":                       integer,
+      "cache_mem":                        integer,
+      "inactive_mem":                     integer,
+      "active_mem":                       integer,
+      "swap_in":                          integer,
+      "swap_out":                         integer,
+      "blocks_in":                        integer,
+      "blocks_out":                       integer,
+      "interrupts":                       integer,
+      "context_switches":                 integer,
+      "user_time":                        integer,
+      "system_time":                      integer,
+      "idle_time":                        integer,
+      "io_wait_time":                     integer,
+      "stolen_time":                      integer,
+      "disk":                             string,
+      "total_reads":                      integer,
+      "merged_reads":                     integer,
+      "sectors_read":                     integer,
+      "reading_ms":                       integer,
+      "total_writes":                     integer,
+      "merged_writes":                    integer,
+      "sectors_written":                  integer,
+      "writing_ms":                       integer,
+      "current_io":                       integer,
+      "io_seconds":                       integer,
+      "timestamp":                        string,
+      "timezone":                         string,
+      "epoch":                            integer,     # [0]
+      "epoch_utc":                        integer      # [1]
+
+      # Below object only exists if using -qq or ignore_exceptions=True
+
+      "_jc_meta":
         {
-          "success":                       boolean,     # true if successfully parsed, false if error
-          "error":                         string,      # exists if "success" is false
-          "line":                          string       # exists if "success" is false
+          "success":                      boolean,  # [2]
+          "error":                        string,   # [3]
+          "line":                         string    # [3]
         }
     }
 
+    [0] naive timestamp if -t flag is used
+    [1] aware timestamp if -t flag is used and UTC TZ
+    [2] false if error parsing
+    [3] exists if "success" is false
+
 Examples:
 
     $ vmstat | jc --vmstat-s
-    {"runnable_procs":2,"uninterruptible_sleeping_procs":0,"virtual_mem_used":0,"free_mem":2794468,"buffer_mem":2108,"cache_mem":741208,"inactive_mem":null,"active_mem":null,"swap_in":0,"swap_out":0,"blocks_in":1,"blocks_out":3,"interrupts":29,"context_switches":57,"user_time":0,"system_time":0,"idle_time":99,"io_wait_time":0,"stolen_time":0,"timestamp":null,"timezone":null}
+    {"runnable_procs":2,"uninterruptible_sleeping_procs":0,"virtual_mem...}
     ...
 
     $ vmstat | jc --vmstat-s -r
-    {"runnable_procs":"2","uninterruptible_sleeping_procs":"0","virtual_mem_used":"0","free_mem":"2794468","buffer_mem":"2108","cache_mem":"741208","inactive_mem":null,"active_mem":null,"swap_in":"0","swap_out":"0","blocks_in":"1","blocks_out":"3","interrupts":"29","context_switches":"57","user_time":"0","system_time":"0","idle_time":"99","io_wait_time":"0","stolen_time":"0","timestamp":null,"timezone":null}
+    {"runnable_procs":"2","uninterruptible_sleeping_procs":"0","virtua...}
     ...
 """
 import jc.utils
@@ -87,8 +111,6 @@ class info():
     description = '`vmstat` command streaming parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
-
-    # compatible options: linux, darwin, cygwin, win32, aix, freebsd
     compatible = ['linux']
     streaming = True
 
@@ -108,11 +130,13 @@ def _process(proc_data):
 
         Dictionary. Structured data to conform to the schema.
     """
-    int_list = ['runnable_procs', 'uninterruptible_sleeping_procs', 'virtual_mem_used', 'free_mem', 'buffer_mem',
-                'cache_mem', 'inactive_mem', 'active_mem', 'swap_in', 'swap_out', 'blocks_in', 'blocks_out',
-                'interrupts', 'context_switches', 'user_time', 'system_time', 'idle_time', 'io_wait_time',
-                'stolen_time', 'total_reads', 'merged_reads', 'sectors_read', 'reading_ms', 'total_writes',
-                'merged_writes', 'sectors_written', 'writing_ms', 'current_io', 'io_seconds']
+    int_list = [
+        'runnable_procs', 'uninterruptible_sleeping_procs', 'virtual_mem_used', 'free_mem',
+        'buffer_mem', 'cache_mem', 'inactive_mem', 'active_mem', 'swap_in', 'swap_out', 'blocks_in',
+        'blocks_out', 'interrupts', 'context_switches', 'user_time', 'system_time', 'idle_time',
+        'io_wait_time', 'stolen_time', 'total_reads', 'merged_reads', 'sectors_read', 'reading_ms',
+        'total_writes', 'merged_writes', 'sectors_written', 'writing_ms', 'current_io', 'io_seconds'
+    ]
 
     for key in proc_data:
         if key in int_list:
@@ -132,8 +156,10 @@ def parse(data, raw=False, quiet=False, ignore_exceptions=False):
 
     Parameters:
 
-        data:              (iterable)  line-based text data to parse (e.g. sys.stdin or str.splitlines())
-        raw:               (boolean)   output preprocessed JSON if True
+        data:              (iterable)  line-based text data to parse
+                                       (e.g. sys.stdin or str.splitlines())
+
+        raw:               (boolean)   unprocessed output if True
         quiet:             (boolean)   suppress warning messages if True
         ignore_exceptions: (boolean)   ignore parsing exceptions if True
 
